pub struct Packet { /* private fields */ }Expand description
Reviewable packet handed to staff or agents with deterministic gates already applied.
Implementations
Sourceimpl Packet
impl Packet
Sourcepub const fn reservation_id(&self) -> Id
pub const fn reservation_id(&self) -> Id
Returns the reservation id evidence available to retention follow-up review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn customer_id(&self) -> CustomerId
pub const fn customer_id(&self) -> CustomerId
Returns the customer id evidence available to retention follow-up review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn eligibility(&self) -> FollowUpEligibility
pub const fn eligibility(&self) -> FollowUpEligibility
Returns the eligibility evidence available to retention follow-up review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn draft_channel(&self) -> Option<Channel>
pub const fn draft_channel(&self) -> Option<Channel>
Returns the draft channel evidence available to retention follow-up review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn review_packet(&self) -> &StaffReviewPacket
pub const fn review_packet(&self) -> &StaffReviewPacket
Returns the review packet evidence available to retention follow-up review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub fn required_review_gates(&self) -> &[ReviewGate]
pub fn required_review_gates(&self) -> &[ReviewGate]
Returns the required review gates evidence available to retention follow-up review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub fn safe_agent_actions(&self) -> &[SafeAgentAction]
pub fn safe_agent_actions(&self) -> &[SafeAgentAction]
Returns the safe agent actions evidence available to retention follow-up review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub fn blocked_actions(&self) -> &[BlockedAction]
pub fn blocked_actions(&self) -> &[BlockedAction]
Returns the blocked actions evidence available to retention follow-up review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub fn source_record_refs(&self) -> &[RecordRef]
pub fn source_record_refs(&self) -> &[RecordRef]
Returns the source record refs evidence available to retention follow-up review while leaving provider, customer, payment, and schedule systems unchanged.