pub struct Request { /* private fields */ }Expand description
Input rules for building the workflow packet from source-grounded records.
Implementations
Sourceimpl Request
impl Request
Sourcepub fn builder() -> RequestBuilder
pub fn builder() -> RequestBuilder
Create an instance of Request using the builder syntax
Sourceimpl Request
impl Request
Sourcepub const fn reservation_id(&self) -> Id
pub const fn reservation_id(&self) -> Id
Returns the reservation id evidence available to retention follow-up review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn customer_id(&self) -> CustomerId
pub const fn customer_id(&self) -> CustomerId
Returns the customer id evidence available to retention follow-up review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn checkout_packet(&self) -> &Packet
pub const fn checkout_packet(&self) -> &Packet
Returns the checkout packet evidence available to retention follow-up review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub const fn contact_permission(&self) -> &ContactPermission
pub const fn contact_permission(&self) -> &ContactPermission
Returns the contact permission evidence available to retention follow-up review while leaving provider, customer, payment, and schedule systems unchanged.
Sourcepub fn opportunities(&self) -> &[RetentionOpportunity]
pub fn opportunities(&self) -> &[RetentionOpportunity]
Returns the opportunities evidence available to retention follow-up review while leaving provider, customer, payment, and schedule systems unchanged.