pub struct RetentionOpportunity { /* private fields */ }Expand description
Retention opportunity carried by the retention follow-up workflow; it turns source-grounded visit evidence into safe follow-up drafts without sending customer messages automatically.
Implementations
Sourceimpl RetentionOpportunity
impl RetentionOpportunity
Sourcepub fn builder() -> RetentionOpportunityBuilder
pub fn builder() -> RetentionOpportunityBuilder
Create an instance of RetentionOpportunity using the builder syntax
Sourceimpl RetentionOpportunity
impl RetentionOpportunity
Sourcepub const fn kind(&self) -> OpportunityKind
pub const fn kind(&self) -> OpportunityKind
Returns the kind source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn evidence(&self) -> &OpportunityEvidence
pub const fn evidence(&self) -> &OpportunityEvidence
Returns the evidence source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.