pub struct StaffReviewPacket { /* private fields */ }Expand description
Staff-facing packet that explains the evidence, draft limits, and required review gates.
Implementations
Sourceimpl StaffReviewPacket
impl StaffReviewPacket
Sourcepub const fn reservation_id(&self) -> Id
pub const fn reservation_id(&self) -> Id
Returns the reservation id source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn customer_id(&self) -> CustomerId
pub const fn customer_id(&self) -> CustomerId
Returns the customer id source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn eligibility(&self) -> FollowUpEligibility
pub const fn eligibility(&self) -> FollowUpEligibility
Returns the eligibility source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn draft_channel(&self) -> Option<Channel>
pub const fn draft_channel(&self) -> Option<Channel>
Returns the draft channel source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn staff_evidence(&self) -> &[OpportunityEvidence]
pub fn staff_evidence(&self) -> &[OpportunityEvidence]
Returns the staff evidence source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn required_review_gates(&self) -> &[ReviewGate]
pub fn required_review_gates(&self) -> &[ReviewGate]
Returns the required review gates source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn requires_human_review(&self) -> bool
pub fn requires_human_review(&self) -> bool
Reports whether the retention follow-up workflow satisfies the requires human review safety condition.