pub struct OpportunityEvidence { /* private fields */ }Expand description
Opportunity evidence carried by the retention follow-up workflow; it turns source-grounded visit evidence into safe follow-up drafts without sending customer messages automatically.
Implementations
Sourceimpl OpportunityEvidence
impl OpportunityEvidence
Sourcepub fn builder() -> OpportunityEvidenceBuilder
pub fn builder() -> OpportunityEvidenceBuilder
Create an instance of OpportunityEvidence using the builder syntax
Sourceimpl OpportunityEvidence
impl OpportunityEvidence
Sourcepub const fn reason_code(&self) -> SourceGroundedReasonCode
pub const fn reason_code(&self) -> SourceGroundedReasonCode
Returns the reason code source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn summary(&self) -> &EvidenceSummary
pub const fn summary(&self) -> &EvidenceSummary
Returns the summary source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn provenance(&self) -> &Provenance
pub const fn provenance(&self) -> &Provenance
Returns the provenance source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.