pub struct OutcomeRecord { /* private fields */ }Expand description
Outcome record carried by the retention follow-up workflow; it turns source-grounded visit evidence into safe follow-up drafts without sending customer messages automatically.
Implementations
Sourceimpl OutcomeRecord
impl OutcomeRecord
Sourcepub fn builder() -> OutcomeRecordBuilder
pub fn builder() -> OutcomeRecordBuilder
Create an instance of OutcomeRecord using the builder syntax
Sourceimpl OutcomeRecord
impl OutcomeRecord
Sourcepub const fn reservation_id(&self) -> Id
pub const fn reservation_id(&self) -> Id
Returns the reservation id source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn customer_id(&self) -> CustomerId
pub const fn customer_id(&self) -> CustomerId
Returns the customer id source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn recorded_by(&self) -> &ActorRef
pub const fn recorded_by(&self) -> &ActorRef
Returns the recorded by source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn recorded_at(&self) -> DateTime<Utc>
pub const fn recorded_at(&self) -> DateTime<Utc>
Returns the recorded at source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn outcome(&self) -> FollowUpOutcome
pub const fn outcome(&self) -> FollowUpOutcome
Returns the outcome source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn source_provenance(&self) -> &Provenance
pub const fn source_provenance(&self) -> &Provenance
Returns the source provenance source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn evidence(&self) -> &[OpportunityEvidence]
pub fn evidence(&self) -> &[OpportunityEvidence]
Returns the evidence source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn records_staff_evidence_only(&self) -> bool
pub const fn records_staff_evidence_only(&self) -> bool
Returns the records staff evidence only source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn blocked_actions(&self) -> Vec<BlockedAction>
pub fn blocked_actions(&self) -> Vec<BlockedAction>
Returns the blocked actions source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.