pub struct Packet { /* private fields */ }Expand description
Reviewable packet handed to staff or agents with deterministic gates already applied.
Implementations
Sourceimpl Packet
impl Packet
Sourcepub const fn reservation_id(&self) -> Id
pub const fn reservation_id(&self) -> Id
Returns the reservation id source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn customer_id(&self) -> CustomerId
pub const fn customer_id(&self) -> CustomerId
Returns the customer id source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn eligibility(&self) -> FollowUpEligibility
pub const fn eligibility(&self) -> FollowUpEligibility
Returns the eligibility source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn draft_channel(&self) -> Option<Channel>
pub const fn draft_channel(&self) -> Option<Channel>
Returns the draft channel source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn review_packet(&self) -> &StaffReviewPacket
pub const fn review_packet(&self) -> &StaffReviewPacket
Returns the review packet source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn required_review_gates(&self) -> &[ReviewGate]
pub fn required_review_gates(&self) -> &[ReviewGate]
Returns the required review gates source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn safe_agent_actions(&self) -> &[SafeAgentAction]
pub fn safe_agent_actions(&self) -> &[SafeAgentAction]
Returns the safe agent actions source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn blocked_actions(&self) -> &[BlockedAction]
pub fn blocked_actions(&self) -> &[BlockedAction]
Returns the blocked actions source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn source_record_refs(&self) -> &[RecordRef]
pub fn source_record_refs(&self) -> &[RecordRef]
Returns the source record refs source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.