pub struct Request { /* private fields */ }Expand description
Input contract for building the workflow packet from source-grounded records.
Implementations
Sourceimpl Request
impl Request
Sourcepub fn builder() -> RequestBuilder
pub fn builder() -> RequestBuilder
Create an instance of Request using the builder syntax
Sourceimpl Request
impl Request
Sourcepub const fn reservation_id(&self) -> Id
pub const fn reservation_id(&self) -> Id
Returns the reservation id source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn customer_id(&self) -> CustomerId
pub const fn customer_id(&self) -> CustomerId
Returns the customer id source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn checkout_packet(&self) -> &Packet
pub const fn checkout_packet(&self) -> &Packet
Returns the checkout packet source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub const fn contact_permission(&self) -> &ContactPermission
pub const fn contact_permission(&self) -> &ContactPermission
Returns the contact permission source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.
Sourcepub fn opportunities(&self) -> &[RetentionOpportunity]
pub fn opportunities(&self) -> &[RetentionOpportunity]
Returns the opportunities source evidence carried by this retention follow-up workflow artifact without changing provider, customer, payment, or schedule state.